@@ -8,6 +8,13 @@ sub collapse {
     return $val;
 }
 
+sub flatten {
+    my ($self, $val) = @_;
+
+    $val =~ s/\s//g;
+    return $val;
+}
+
 sub lower {
     my ($self, $val) = @_;
 
@@ -70,6 +77,10 @@ used commonly.
 
 Collapses all consecutive whitespace into a single space
 
+=head2 flatten
+
+Removes B<all whitespace>.
+
 =head2 lower
 
 Converts the value to lowercase.
